==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/lt-LT/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Patvirtinkite masinį turto panaikinimą',
    'bulk_restore'      => 'Patvirtinkite masinį turto atkūrimą', 
  'bulk_delete_help'	=> 'Peržiūrėkite turtą, kurį norite panaikinti. Panaikintą turtą galima atkurti, tačiau jis nebebus susietas su tais naudotojais, kuriems šiuo metu yra išduotas.',
  'bulk_restore_help'	=> 'Peržiūrėkite turtą, kurį norite atkurti. Atkūrus turtą, jis nebus susietas su tais naudotojais, kuriems anksčiau buvo išduotas.',
  'bulk_delete_warn'	=> 'Bus panaikinta turto vienetų: :asset_count.',
  'bulk_restore_warn'	=> 'Bus atkurta turto vienetų: :asset_count.',
    'bulk_update'		=> 'Masinis turto atnaujinimas',
    'bulk_update_help'	=> 'Ši forma suteikia galimybę atnaujinti iškart kelis turto vienetus. Užpildykite tik tuos laukus, kuriuos norite pakeisti. Laukai, kuriuos paliksite tuščius, liks nepakeisti. ',
    'bulk_update_warn'	=> 'Ketinate redaguoti vieno turto vieneto ypatybes.|Ketinate redaguoti :asset_count turto vienetų ypatybes.',
    'bulk_update_with_custom_field' => 'Atminkite, kad turtas yra :asset_model_count skirtingų modelių tipų.',
    'bulk_update_model_prefix' => 'Modeliams', 
    'bulk_update_custom_field_unique' => 'Tai unikalus laukas, todėl jo negalima redaguoti masinio redagavimo būdu.',
    'checkedout_to'		=> 'Kam išduota',
    'checkout_date'		=> 'Išdavimo data',
    'checkin_date'		=> 'Paėmimo data',
    'checkout_to'		=> 'Išduoti',
    'cost'				=> 'Įsigijimo kaina',
    'create'			=> 'Sukurti turtą',
    'date'				=> 'Įsigijimo data',
    'depreciation'	    => 'Nusidėvėjimas',
    'depreciates_on'	=> 'Nusidėvėjimo data',
    'default_location'	=> 'Numatytoji vieta',
    'default_location_phone' => 'Numatytosios vietos telefono numeris',
    'eol_date'			=> 'Nurašymo data',
    'eol_rate'			=> 'Laikas iki nurašymo',
    'expected_checkin'  => 'Numatoma paėmimo data',
    'expires'			=> 'Baigsis',
    'fully_depreciated'	=> 'Visiškai nusidėvėjo',
    'help_checkout'		=> 'Jei norite nedelsiant išduoti šį turtą, aukščiau esančiame būsenų sąraše pasirinkite „Paruoštas naudojimui“. ',
    'mac_address'		=> 'MAC adresas',
    'manufacturer'		=> 'Gamintojas',
    'model'				=> 'Modelis',
    'months'			=> 'mėnesiai',
    'name'				=> 'Turto pavadinimas',
    'notes'				=> 'Pastabos',
    'order'				=> 'Užsakymo numeris',
    'qr'				=> 'QR kodas',
    'requestable'		=> 'Naudotojai gali užsakyti šį turtą',
    'redirect_to_all'   => 'Grįžti prie visų :type',
    'redirect_to_type'   => 'Eiti į :type',
    'redirect_to_checked_out_to'   => 'Eiti į išduotus',
    'select_statustype'	=> 'Pasirinkite būsenos tipą',
    'serial'			=> 'Serijinis numeris',
    'status'			=> 'Būsena',
    'tag'				=> 'Inventorinis numeris',
    'update'			=> 'Turto atnaujinimas',
    'warranty'			=> 'Garantija',
        'warranty_expires'		=> 'Garantija baigiasi',
    'years'				=> 'metai',
    'asset_location' => 'Atnaujinti turto vietą',
    'asset_location_update_default_current' => 'Atnaujinti numatytąją vietą IR faktinę vietą',
    'asset_location_update_default' => 'Atnaujinti tik numatytąją vietą',
    'asset_location_update_actual' => 'Atnaujinti tik faktinę vietą',
    'asset_not_deployable' => 'Turto būsena netinkama išdavimui, todėl šis turtas negali būti išduotas.',
    'asset_not_deployable_checkin' => 'Turto su šia būsenos žyma išduoti negalima. Nustačius šią būsenos žymą, turtas bus paimtas.',
    'asset_deployable' => 'Turto būsena tinkama išdavimui, todėl šis turtas gali būti išduotas.',
    'processing_spinner' => 'Apdorojama... (Dideliems failams gali šiek tiek užtrukti)',
    'optional_infos'  => 'Papildoma informacija',
    'order_details'   => 'Su užsakymu susijusi informacija',
    'calc_eol'    => 'Jei EOL data nustatoma iš naujo, naudoti automatinį EOL apskaičiavimą pagal įsigijimo datą ir nusidėvėjimo laipsnį.',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/lt-LT/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Patvirtinkite masinį turto panaikinimą',
    'bulk_restore'      => 'Patvirtinkite masinį turto atkūrimą', 
  'bulk_delete_help'	=> 'Peržiūrėkite turtą, kurį norite panaikinti. Panaikintą turtą galima atkurti, tačiau jis nebebus susietas su tais naudotojais, kuriems šiuo metu yra išduotas.',
  'bulk_restore_help'	=> 'Peržiūrėkite turtą, kurį norite atkurti. Atkūrus turtą, jis nebus susietas su tais naudotojais, kuriems anksčiau buvo išduotas.',
  'bulk_delete_warn'	=> 'Bus panaikinta turto vienetų: :asset_count.',
  'bulk_restore_warn'	=> 'Bus atkurta turto vienetų: :asset_count.',
    'bulk_update'		=> 'Masinis turto atnaujinimas',
    'bulk_update_help'	=> 'Ši forma suteikia galimybę atnaujinti iškart kelis turto vienetus. Užpildykite tik tuos laukus, kuriuos norite pakeisti. Laukai, kuriuos paliksite tuščius, liks nepakeisti. ',
    'bulk_update_warn'	=> 'Ketinate redaguoti vieno turto vieneto ypatybes.|Ketinate redaguoti :asset_count turto vienetų ypatybes.',
    'bulk_update_with_custom_field' => 'Atminkite, kad turtas yra :asset_model_count skirtingų modelių tipų.',
    'bulk_update_model_prefix' => 'Modeliams', 
    'bulk_update_custom_field_unique' => 'Tai unikalus laukas, todėl jo negalima redaguoti masinio redagavimo būdu.',
    'checkedout_to'		=> 'Kam išduota',
    'checkout_date'		=> 'Išdavimo data',
    'checkin_date'		=> 'Paėmimo data',
    'checkout_to'		=> 'Išduoti',
    'cost'				=> 'Įsigijimo kaina',
    'create'			=> 'Sukurti turtą',
    'date'				=> 'Įsigijimo data',
    'depreciation'	    => 'Nusidėvėjimas',
    'depreciates_on'	=> 'Nusidėvėjimo data',
    'default_location'	=> 'Numatytoji vieta',
    'default_location_phone' => 'Numatytosios vietos telefono numeris',
    'eol_date'			=> 'Nurašymo data',
    'eol_rate'			=> 'Laikas iki nurašymo',
    'expected_checkin'  => 'Numatoma paėmimo data',
    'expires'			=> 'Baigsis',
    'fully_depreciated'	=> 'Visiškai nusidėvėjo',
    'help_checkout'		=> 'Jei norite nedelsiant išduoti šį turtą, aukščiau esančiame būsenų sąraše pasirinkite „Paruoštas naudojimui“. ',
    'mac_address'		=> 'MAC adresas',
    'manufacturer'		=> 'Gamintojas',
    'model'				=> 'Modelis',
    'months'			=> 'mėnesiai',
    'name'				=> 'Turto pavadinimas',
    'notes'				=> 'Pastabos',
    'order'				=> 'Užsakymo numeris',
    'qr'				=> 'QR kodas',
    'requestable'		=> 'Naudotojai gali užsakyti šį turtą',
    'redirect_to_all'   => 'Grįžti prie visų :type',
    'redirect_to_type'   => 'Eiti į :type',
    'redirect_to_checked_out_to'   => 'Eiti į išduotus',
    'select_statustype'	=> 'Pasirinkite būsenos tipą',
    'serial'			=> 'Serijinis numeris',
    'serial_required'	=> 'Turtui :number būtina nurodyti serijinį numerį',
    'serial_required_post_model_update'	=> ':asset_model have been updated to require a serial number. Please add a serial number for this asset.',
    'status'			=> 'Būsena',
    'tag'				=> 'Inventorinis numeris',
    'update'			=> 'Turto atnaujinimas',
    'warranty'			=> 'Garantija',
        'warranty_expires'		=> 'Garantija baigiasi',
    'years'				=> 'metai',
    'asset_location' => 'Atnaujinti turto vietą',
    'asset_location_update_default_current' => 'Atnaujinti numatytąją vietą IR faktinę vietą',
    'asset_location_update_default' => 'Atnaujinti tik numatytąją vietą',
    'asset_location_update_actual' => 'Atnaujinti tik faktinę vietą',
    'asset_not_deployable' => 'Turto būsena netinkama išdavimui, todėl šis turtas negali būti išduotas.',
    'asset_not_deployable_checkin' => 'Turto su šia būsenos žyma išduoti negalima. Nustačius šią būsenos žymą, turtas bus paimtas.',
    'asset_deployable' => 'Šį turtą galima išduoti.',
    'processing_spinner' => 'Apdorojama... (Dideliems failams gali šiek tiek užtrukti)',
    'processing' => 'Vykdoma... ',
    'optional_infos'  => 'Papildoma informacija',
    'order_details'   => 'Su užsakymu susijusi informacija',
    'calc_eol'    => 'Jei EOL data nustatoma iš naujo, naudoti automatinį EOL apskaičiavimą pagal įsigijimo datą ir nusidėvėjimo laipsnį.',
];
